@@ -842,15 +842,17 @@ class Experiment(object):
                 for org in self.sumexp[pid][wid]:
                     reps = self.experiment[pid][wid][org].keys()
                     
-                    act = []
-                    for r in reps:
-                        if self.experiment[pid][wid][org][r].activity is None:
-                            break
-                        act.append(self.experiment[pid][wid][org][r].activity)
+                    # Keep track of all mean parameters
+                    for param in Well('phony', 'phony').params + ['activity']:
+                        act = []
+                        for r in reps:
+                            if getattr(self.experiment[pid][wid][org][r], param) is None:
+                                break
+                            act.append(getattr(self.experiment[pid][wid][org][r], param))
                         
-                    if len(act) > 0:
-                        mean = np.array(act).mean()
-                        self.sumexp[pid][wid][org].activity = mean
+                        if len(act) > 0:
+                            mean = np.array(act).mean()
+                            setattr(self.sumexp[pid][wid][org], param, mean)
     
     def getMax(self):
         '''
@@ -1049,13 +1051,21 @@ class Experiment(object):
             for strain in d:
                 yield d[strain]
     
-    def trim(self):
+    def trim(self, trimTime = None):
         '''
         Set the maximum time for each well by using the lowest value in the
         experiment.
         Returns the trim time.
+
+        If trimTime is set, that time will be used
         '''
-        mtime = self.getMinTime()
+        if trimTime is not None:
+            mtime = trimTime
+            if mtime > self.getMaxTime():
+                logger.warning('Selected trim time > then max time (%f vs. %f)'%(
+                                mtime, self.getMaxTime()))
+        else:
+            mtime = self.getMinTime()
         
         for w in self.getWells(False):
             to_del = set()
@@ -1224,12 +1234,24 @@ class Experiment(object):
         '''
         return max([w.activity for w in self.getWells(False)])
     
+    def getMaxParam(self, param):
+        '''
+        Get the maximum value for a certain parameter
+        '''
+        return max([getattr(w, param) for w in self.getWells()])
+    
     def getMinTime(self):
         '''
         Get the minimum time
         '''
         return min([w.getMaxTime() for w in self.getWells(False)])
     
+    def getMaxTime(self):
+        '''
+        Get the maximum time
+        '''
+        return max([w.getMaxTime() for w in self.getWells(False)])
+    
     def setMaxParams(self):
         '''
         Find the maximum value of each parameter
@@ -1608,12 +1630,12 @@ class BiologParser(object):
     def parse(self):
         try:
             self.parseOPM()
-        except Exception, e:
+        except Exception as e:
             logger.warning('YAML/OPM parsing failed!')
             logger.debug('%s'%e)
             try:
                 self.parseCSV()
-            except Exception, e:
+            except Exception as e:
                 logger.error('CSV parsing failed!')
                 logger.debug('%s'%e)
                 return False
@@ -2712,4 +2734,4 @@ def removeNegatives(value):
     if value < 0.0:
         return 0
     
-    return value
\ No newline at end of file
+    return value
